SMUTHI
=======================
SMUTHI stands for 'scattering by multiple particles in thin-film systems'. The software allows to simulate light
scattering by multiple particles near (or between) planar interfaces. It is based on the T-matrix method for the single
particle scattering, and on the scattering-matrix method for the propagation through the layered medium.

Target group: Scientists and engineers in the field of optics and optoelectronics.

License: SMUTHI is provided under the MIT license.

Author: Amos Egel. Mail to amos.egel@kit.edu for support or to report a problem.

For a guide how to install and use the software, see the `documentation <http://smuthi.readthedocs.io>`_.

What's new in version 0.2
--------------------------
In addition to spherical particles, spheroids can now be selected as scattering particles, too.
Spheroids are ellipsoidal particles with one axis of rotational symmetry (which is currently fixed
to be the direction perpendicular to the layer interfaces).

Planned updates for future versions
------------------------------------
Things to be implemented next:

 - finite cylinders
 - near fields
 - faster evaluation of particle coupling
 - dipole excitation
 - Gaussian beam excitation
